% Code to plot simulation results from the model
%% Plot Description:
%
% The plot below shows drain current vs. gate-source voltage for a range
% of temperatures.
%
% Copyright 2018 The MathWorks, Inc.

load('transfer_data_new');
ModelName = get_param(gcb,'Parent');
ParameterBlk = [ModelName '/Parameters'];
Vg_vec = str2num(get_param(ParameterBlk,'Vg_vec'));
Vds_min = str2num(get_param(ParameterBlk,'Vds_min'));
Vds_max = str2num(get_param(ParameterBlk,'Vds_max'));
if Vds_max <= Vds_min
    pm_error('physmod:elec:library:InconsistentMaskParameters','Maximum drain-source voltage','Minimum drain-source voltage')
end
t_sim = 1;
clear legend_info Id_mat Vds_vec
T_vec= [-55 25 125];

for j=1:length(T_vec)
    T=T_vec(j);
    legend_info{j} = ['T = ',num2str(T)]; %#ok<SAGROW>
    sim(ModelName,t_sim)
    Id_mat(:,j) = Id.signals.values; %#ok<SAGROW>
    Vgs_vec = Vgs.signals.values;
% end

end
% Reuse figure if it exists, else create new figure
if ~exist('h1_elec_mosfet', 'var') || ...
        ~isgraphics(h1_elec_mosfet, 'figure')
    h1_elec_mosfet = figure('Name', 'elec_mosfet');
end
figure(h1_elec_mosfet)
clf(h1_elec_mosfet)

plot(Vgs_vec,Id_mat','LineWidth',1.5)
xlabel('Gate-Source Voltage (V)')
ylabel('Drain Current (A)')
title('MOSFET Curves: Id vs. Vg for Varying Temperatures')
grid on
axis([1 2.5 0 100])
hold on
Id_mat_datasheet4 = Data004(:,2);
Id_mat_datasheet5 = Data005(:,2);
Id_mat_datasheet6 = Data006(:,2);

Vgs_vec_datasheet1 = Data004(:,1); 
Vgs_vec_datasheet2 = Data005(:,1); 
Vgs_vec_datasheet3 = Data006(:,1);

plot(Vgs_vec_datasheet1,Id_mat_datasheet4','--','LineWidth',1.5)
hold on
plot(Vgs_vec_datasheet2,Id_mat_datasheet5','--','LineWidth',1.5)
plot(Vgs_vec_datasheet3,Id_mat_datasheet6','--','LineWidth',1.5)
legend_info{1,4} = 'Datasheet';
legend(legend_info);
% Reset default values
Vg = 5;
Vds_min = 5;
Vds_max = 13;



