% Code to plot simulation results from the model
%% Plot Description:
%
% The plot below shows drain current vs. drain-source voltage for a range
% of gate voltages.
%
% Copyright 2018 The MathWorks, Inc.

load('data_sheet')
ModelName = get_param(gcb,'Parent');
ParameterBlk = [ModelName '/Parameters'];
Vg_vec = str2num(get_param(ParameterBlk,'Vg_vec'));
Vds_min = str2num(get_param(ParameterBlk,'Vds_min'));
Vds_max = str2num(get_param(ParameterBlk,'Vds_max'));
if Vds_max <= Vds_min
    pm_error('physmod:elec:library:InconsistentMaskParameters','Maximum drain-source voltage','Minimum drain-source voltage')
end
T=25;
t_sim = 1;
clear legend_info Id_mat Vds_vec
for i=1:length(Vg_vec)
    Vg = Vg_vec(i);
    legend_info{i} = ['Vg = ',num2str(Vg)]; %#ok<SAGROW>
    sim(ModelName,t_sim)
    Id_mat(:,i) = Id.signals.values; %#ok<SAGROW>
    Vds_vec = Vds.signals.values;
end

% Reuse figure if it exists, else create new figure
if ~exist('h1_elec_mosfet', 'var') || ...
        ~isgraphics(h1_elec_mosfet, 'figure')
    h1_elec_mosfet = figure('Name', 'elec_mosfet');
end
figure(h1_elec_mosfet)
clf(h1_elec_mosfet)

plot(Vds_vec,Id_mat','LineWidth',1.5)
axis([Vds_min Vds_max max(-30,min(min(Id_mat))) min(100,max(max(Id_mat)))])
xlabel('Drain-Source Voltage (V)')
ylabel('Drain Current (A)')

title('MOSFET Curves: Ic vs. Vds for Varying Gate Voltage')
grid on
% Reset default values
hold on
Id_mat_datasheet1 = Data001(:,2);
Id_mat_datasheet2 = Data002(:,2);
Id_mat_datasheet3 = Data003(:,2);

Vds_vec_datasheet1 = Data001(:,1); 
Vds_vec_datasheet2 = Data002(:,1); 
Vds_vec_datasheet3 = Data003(:,1);

plot(Vds_vec_datasheet1,Id_mat_datasheet1','--','LineWidth',1.5)
plot(Vds_vec_datasheet2,Id_mat_datasheet2','--','LineWidth',1.5)
plot(Vds_vec_datasheet3,Id_mat_datasheet3','--','LineWidth',1.5)
legend_info{1,4} = 'Datasheet';
legend(legend_info);
Vg = 5;
Vds_min = 0;
Vds_max = 4;




